@@ -13,7 +13,7 @@ use vars qw($VERSION);
 use Image::ExifTool;    # only for FinishTiffDump()
 use Image::ExifTool::HTML qw(EscapeHTML);
 
-$VERSION = '1.40';
+$VERSION = '1.42';
 
 sub DumpTable($$$;$$$$$$);
 sub Open($$$;@);
@@ -314,6 +314,8 @@ sub Print($$;$$$$$)
     $title = 'HtmlDump' unless $title;
     $level or $level = 0;
     my $tell = $raf->Tell();
+    $raf->Seek(0,2) or $$self{ERROR} = 'Seek error', return -1;
+    my $fileLen = $raf->Tell();
     my $pos = 0;
     my $dataEnd = $dataPos + ($dataPt ? length($$dataPt) : 0);
     # initialize member variables
@@ -352,6 +354,7 @@ sub Print($$;$$$$$)
         } else {
             last;
         }
+        $start = $fileLen if $start > $fileLen; # handle case of bad start offset
         my $len = $start - $pos;
         if ($len > 0 and not $wasUnused) {
             # we have a unused bytes before this data block
@@ -432,8 +435,7 @@ sub Print($$;$$$$$)
                             {
                                 $err = $msg;
                                 # reset $len to the actual length of available data
-                                $raf->Seek(0, 2);
-                                $len = $raf->Tell() - $start;
+                                $len = $fileLen - $start;
                                 $tip .= "<br>Error: Only $len bytes available!" if $tip;
                                 next;
                             }
@@ -767,6 +769,7 @@ sub FinishTiffDump($$$)
         PreviewImageStart => 'PreviewImageLength',
         JpgFromRawStart   => 'JpgFromRawLength',
         OtherImageStart   => 'OtherImageLength',
+        PreviewJXLStart   => 'PreviewJXLLength',
         ImageOffset       => 'ImageByteCount',
         AlphaOffset       => 'AlphaByteCount',
         MPImageStart      => 'MPImageLength',
